Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Macie Classic.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon Macie Classic - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for Amazon Macie Classic

Amazon Macie Classic (service prefix: `macie` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Macie Classic
- Resource Types Defined by Amazon Macie Classic
- Condition Keys for Amazon Macie Classic

## Actions Defined by Amazon Macie Classic

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AssociateMemberAccount | Enables the user to associate a specified AWS account with Amazon Macie as a member account. | Write |  |  |
AssociateS3Resources | Enables the user to associate specified S3 resources with Amazon Macie for monitoring and data classification. | Write |  | aws:SourceArn |
DisassociateMemberAccount | Enables the user to remove the specified member account from Amazon Macie. | Write |  |  |
DisassociateS3Resources | Enables the user to remove specified S3 resources from being monitored by Amazon Macie. | Write |  | aws:SourceArn |
ListMemberAccounts | Enables the user to list all Amazon Macie member accounts for the current Macie master account. | List |  |  |
ListS3Resources | Enables the user to list all the S3 resources associated with Amazon Macie. | List |  |  |
UpdateS3Resources | Enables the user to update the classification types for the specified S3 resources. | Write |  | aws:SourceArn |

## Resource Types Defined by Amazon Macie Classic

Amazon Macie Classic does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon Macie Classic, specify `“Resource”: “*”` in your policy.

## Condition Keys for Amazon Macie Classic

Amazon Macie Classic defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:SourceArn | Allow access to the specified actions only when the request operates on the specified aws resource | Arn

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.